@@ -46,7 +46,6 @@ class NIFTI_interface(Abstract_IO):
         self.classes = classes
         self.three_dim = three_dim
         self.pattern = pattern
-        self.cache = dict()
 
     #---------------------------------------------#
     #                  initialize                 #
@@ -85,10 +84,21 @@ class NIFTI_interface(Abstract_IO):
         vol = nib.load(os.path.join(img_path, "imaging.nii.gz"))
         # Transform NIFTI object to numpy array
         vol_data = vol.get_fdata()
-        # Save spacing in cache
-        self.cache[index] = vol.affine
-        # Return volume
-        return vol_data
+        # Identify correct spacing diagonal
+        spacing_matrix = vol.affine[:3,:3]
+        diagonal_negative = np.diag(spacing_matrix)
+        diagonal_positive = np.diag(spacing_matrix[::-1,:])
+        if np.count_nonzero(diagonal_negative) != 1:
+            spacing = diagonal_negative
+        elif np.count_nonzero(diagonal_positive) != 1:
+            spacing = diagonal_positive
+        else:
+            warnings.warn("Affinity matrix of NIfTI volume can not be parsed.")
+        # Calculate absolute values for voxel spacing
+        spacing = np.absolute(spacing)
+        # Delete cached spacing
+        # Return dictionary
+        return vol_data, {"type":"nifti", "affine":vol.affine, "spacing":spacing}
 
     #---------------------------------------------#
     #              load_segmentation              #
@@ -106,7 +116,7 @@ class NIFTI_interface(Abstract_IO):
         # Transform NIFTI object to numpy array
         seg_data = seg.get_fdata()
         # Return segmentation
-        return seg_data
+        return seg_data #should this also store the matrix in case they are not aligned?
 
     #---------------------------------------------#
     #               load_prediction               #
@@ -131,44 +141,25 @@ class NIFTI_interface(Abstract_IO):
         # Transform NIFTI object to numpy array
         pred_data = pred.get_fdata()
         # Return prediction
-        return pred_data
-
-    #---------------------------------------------#
-    #                 load_details                #
-    #---------------------------------------------#
-    # Parse slice thickness
-    def load_details(self, i):
-        # Parse voxel spacing from affinity matrix of NIfTI
-        spacing_matrix = self.cache[i][:3,:3]
-        # Identify correct spacing diagonal
-        diagonal_negative = np.diag(spacing_matrix)
-        diagonal_positive = np.diag(spacing_matrix[::-1,:])
-        if np.count_nonzero(diagonal_negative) != 1:
-            spacing = diagonal_negative
-        elif np.count_nonzero(diagonal_positive) != 1:
-            spacing = diagonal_positive
-        else:
-            warnings.warn("Affinity matrix of NIfTI volume can not be parsed.")
-        # Calculate absolute values for voxel spacing
-        spacing = np.absolute(spacing)
-        # Delete cached spacing
-        del self.cache[i]
-        # Return detail dictionary
-        return {"spacing":spacing}
+        return pred_data #should this also store the matrix in case they are not aligned?
 
     #---------------------------------------------#
     #               save_prediction               #
     #---------------------------------------------#
     # Write a segmentation prediction into in the NIFTI file format
-    def save_prediction(self, pred, index, output_path):
+    def save_prediction(self, sample, output_path):
         # Resolve location where data should be written
         if not os.path.exists(output_path):
             raise IOError(
                 "Data path, {}, could not be resolved".format(output_path)
             )
+        # Obtain prediction data
+        pred = sample.pred_data.astype(np.uint16)
+        if "affine" in sample.get_extended_data():
+            spacing = sample.get_extended_data()["affine"]
+        else : spacing = None
         # Convert numpy array to NIFTI
-        nifti = nib.Nifti1Image(pred, None)
-        #nifti.get_data_dtype() == pred.dtype
+        nifti = nib.Nifti1Image(pred, spacing)
         # Save segmentation to disk
-        pred_file = str(index) + ".nii.gz"
+        pred_file = str(sample.index) + ".nii.gz"
         nib.save(nifti, os.path.join(output_path, pred_file))
