@@ -56,5 +56,5 @@ class Clipping(Abstract_Subfunction):
     #---------------------------------------------#
     #               Postprocessing                #
     #---------------------------------------------#
-    def postprocessing(self, prediction):
+    def postprocessing(self, sample, prediction):
         return prediction
